#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""
Tests for vela.emulators
"""
from unittest.mock import mock_open, patch

import pytest
from vela.emulators import CasaEmulator


class TestCasaEmulator:
    @pytest.mark.skip("Ignores forger mock.")
    @patch("os.chdir")
    @patch("vela.forger.VelaProduct.forge_products")
    @patch("vela.forger.VelaLog.forge_logs")
    def test_run(self, mock_logs, mock_products, mock_os):
        with patch("vela.forger.forge") as mock_forge:
            CasaEmulator("test/test.json", "test/PPR.xml", "standard_cal").run()
            assert mock_forge.call_count == 1

    @patch("glob.glob")
    @patch("os.chdir")
    def test_check_logs(self, mock_os, mock_glob):
        with patch("builtins.open", mock_open()) as o:
            CasaEmulator("test.json", "PPR.xml", "standard_cal").check_logs()
            assert o.call_count == 0
            assert mock_os.call_count == 1
            assert mock_glob.call_count == 1
